@@ -15,6 +15,8 @@
 #
 import proto  # type: ignore
 
+from grafeas.grafeas_v1.types import intoto_provenance as g_intoto_provenance
+from grafeas.grafeas_v1.types import intoto_statement as g_intoto_statement
 from grafeas.grafeas_v1.types import provenance as g_provenance
 
 
@@ -42,8 +44,7 @@ class BuildOccurrence(proto.Message):
 
     Attributes:
         provenance (grafeas.grafeas_v1.types.BuildProvenance):
-            Required. The actual provenance for the
-            build.
+            The actual provenance for the build.
         provenance_bytes (str):
             Serialized JSON representation of the provenance, used in
             generating the build signature in the corresponding build
@@ -57,12 +58,27 @@ class BuildOccurrence(proto.Message):
             The serialized form is captured both to avoid ambiguity in
             how the provenance is marshalled to json as well to prevent
             incompatibilities with future changes.
+        intoto_provenance (grafeas.grafeas_v1.types.InTotoProvenance):
+            Deprecated. See InTotoStatement for the
+            replacement. In-toto Provenance representation
+            as defined in spec.
+        intoto_statement (grafeas.grafeas_v1.types.InTotoStatement):
+            In-toto Statement representation as defined in spec. The
+            intoto_statement can contain any type of provenance. The
+            serialized payload of the statement can be stored and signed
+            in the Occurrence's envelope.
     """
 
     provenance = proto.Field(
         proto.MESSAGE, number=1, message=g_provenance.BuildProvenance,
     )
     provenance_bytes = proto.Field(proto.STRING, number=2,)
+    intoto_provenance = proto.Field(
+        proto.MESSAGE, number=3, message=g_intoto_provenance.InTotoProvenance,
+    )
+    intoto_statement = proto.Field(
+        proto.MESSAGE, number=4, message=g_intoto_statement.InTotoStatement,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
