@@ -19,24 +19,14 @@ from google.protobuf import timestamp_pb2  # type: ignore
 from grafeas.grafeas_v1.types import common
 from grafeas.grafeas_v1.types import cvss
 from grafeas.grafeas_v1.types import package
+from grafeas.grafeas_v1.types import severity as g_severity
 
 
 __protobuf__ = proto.module(
-    package="grafeas.v1",
-    manifest={"Severity", "VulnerabilityNote", "VulnerabilityOccurrence",},
+    package="grafeas.v1", manifest={"VulnerabilityNote", "VulnerabilityOccurrence",},
 )
 
 
-class Severity(proto.Enum):
-    r"""Note provider assigned severity/impact ranking."""
-    SEVERITY_UNSPECIFIED = 0
-    MINIMAL = 1
-    LOW = 2
-    MEDIUM = 3
-    HIGH = 4
-    CRITICAL = 5
-
-
 class VulnerabilityNote(proto.Message):
     r"""A security vulnerability that can be found in resources.
 
@@ -204,7 +194,7 @@ class VulnerabilityNote(proto.Message):
         )
 
     cvss_score = proto.Field(proto.FLOAT, number=1,)
-    severity = proto.Field(proto.ENUM, number=2, enum="Severity",)
+    severity = proto.Field(proto.ENUM, number=2, enum=g_severity.Severity,)
     details = proto.RepeatedField(proto.MESSAGE, number=3, message=Detail,)
     cvss_v3 = proto.Field(proto.MESSAGE, number=4, message=cvss.CVSSv3,)
     windows_details = proto.RepeatedField(
@@ -231,7 +221,7 @@ class VulnerabilityOccurrence(proto.Message):
             vulnerability. CVSS score is on a scale of 0 -
             10 where 0 indicates low severity and 10
             indicates high severity.
-        cvssv3 (grafeas.grafeas_v1.types.VulnerabilityOccurrence.CVSSV3):
+        cvssv3 (grafeas.grafeas_v1.types.CVSS):
             The cvss v3 score for the vulnerability.
         package_issue (Sequence[grafeas.grafeas_v1.types.VulnerabilityOccurrence.PackageIssue]):
             Required. The set of affected locations and
@@ -265,21 +255,6 @@ class VulnerabilityOccurrence(proto.Message):
             affected packages has a fix available.
     """
 
-    class CVSSV3(proto.Message):
-        r"""The CVSS v3 score for this vulnerability.
-
-        Attributes:
-            base_score (float):
-                The base score for for this vulnerability
-                according to cvss v3.
-            severity (grafeas.grafeas_v1.types.Severity):
-                The severity rating assigned to this
-                vulnerability by vulnerability provider.
-        """
-
-        base_score = proto.Field(proto.FLOAT, number=1,)
-        severity = proto.Field(proto.ENUM, number=2, enum="Severity",)
-
     class PackageIssue(proto.Message):
         r"""A detail for a distro and package this vulnerability
         occurrence was found in and its associated fix (if one is
@@ -331,19 +306,21 @@ class VulnerabilityOccurrence(proto.Message):
         fixed_version = proto.Field(proto.MESSAGE, number=6, message=package.Version,)
         fix_available = proto.Field(proto.BOOL, number=7,)
         package_type = proto.Field(proto.STRING, number=8,)
-        effective_severity = proto.Field(proto.ENUM, number=9, enum="Severity",)
+        effective_severity = proto.Field(
+            proto.ENUM, number=9, enum=g_severity.Severity,
+        )
 
     type_ = proto.Field(proto.STRING, number=1,)
-    severity = proto.Field(proto.ENUM, number=2, enum="Severity",)
+    severity = proto.Field(proto.ENUM, number=2, enum=g_severity.Severity,)
     cvss_score = proto.Field(proto.FLOAT, number=3,)
-    cvssv3 = proto.Field(proto.MESSAGE, number=10, message=CVSSV3,)
+    cvssv3 = proto.Field(proto.MESSAGE, number=10, message=cvss.CVSS,)
     package_issue = proto.RepeatedField(proto.MESSAGE, number=4, message=PackageIssue,)
     short_description = proto.Field(proto.STRING, number=5,)
     long_description = proto.Field(proto.STRING, number=6,)
     related_urls = proto.RepeatedField(
         proto.MESSAGE, number=7, message=common.RelatedUrl,
     )
-    effective_severity = proto.Field(proto.ENUM, number=8, enum="Severity",)
+    effective_severity = proto.Field(proto.ENUM, number=8, enum=g_severity.Severity,)
     fix_available = proto.Field(proto.BOOL, number=9,)
 
 
